import { world, system, BlockTypes } from '@minecraft/server'

world.afterEvents.playerBreakBlock.subscribe(f => {
    if (!f.player.isSneaking) {
        const { x, y, z } = f.block.location
        randomLoot(x, y, z, f.dimension)
    }
})

const randomLoot = (x, y, z, dimension) => system.run(() => {
    const random = Math.floor(Math.random() * 3 + 1)
    if (random === 1) {
        const lootTable = Math.floor(Math.random() * 376) + 1
        dimension.runCommand(`execute run loot spawn ${x + 0.5} ${y + 0.5} ${z + 0.5} loot "${lootTable}"`)
    }
    else if (random === 2) {
        const randomEntity = entities[Math.floor(Math.random() * entities.length)]
        try {
            dimension.spawnEntity(randomEntity, { x: x + 0.5, y: y, z: z + 0.5 })
        }
        catch (e) { randomLoot(x, y, z, dimension) }
    }
    else if (random === 3) {
        try {
            const randomBlock = blocks[Math.floor(Math.random() * blocks.length)]
            dimension.fillBlocks({ x, y, z }, { x, y, z }, BlockTypes.get(`${randomBlock}`))
        } 
        catch (e) { randomLoot(x, y, z, dimension) }
    }
})

const entities = [
    'minecraft:chicken',
    'minecraft:bee',
    'minecraft:cow',
    'minecraft:pig',
    'minecraft:sheep',
    'minecraft:wolf',
    'minecraft:polar_bear',
    'minecraft:ocelot',
    'minecraft:cat',
    'minecraft:mooshroom',
    'minecraft:bat',
    'minecraft:parrot',
    'minecraft:rabbit',
    'minecraft:llama',
    'minecraft:horse',
    'minecraft:donkey',
    'minecraft:mule',
    'minecraft:skeleton_horse',
    'minecraft:zombie_horse',
    'minecraft:tropicalfish',
    'minecraft:cod',
    'minecraft:pufferfish',
    'minecraft:salmon',
    'minecraft:dolphin',
    'minecraft:turtle',
    'minecraft:panda',
    'minecraft:fox',
    'minecraft:creeper',
    'minecraft:enderman',
    'minecraft:silverfish',
    'minecraft:skeleton',
    'minecraft:wither_skeleton',
    'minecraft:stray',
    'minecraft:slime',
    'minecraft:spider',
    'minecraft:zombie',
    'minecraft:zombie_pigman',
    'minecraft:husk',
    'minecraft:drowned',
    'minecraft:squid',
    'minecraft:glow_squid',
    'minecraft:cave_spider',
    'minecraft:witch',
    'minecraft:guardian',
    'minecraft:elder_guardian',
    'minecraft:endermite',
    'minecraft:magma_cube',
    'minecraft:strider',
    'minecraft:hoglin',
    'minecraft:piglin',
    'minecraft:zoglin',
    'minecraft:piglin_brute',
    'minecraft:goat',
    'minecraft:axolotl',
    'minecraft:allay',
    'minecraft:frog',
    'minecraft:tadpole',
    'minecraft:trader_llama',
    'minecraft:camel',
    'minecraft:ghast',
    'minecraft:blaze',
    'minecraft:shulker',
    'minecraft:vindicator',
    'minecraft:evocation_illager',
    'minecraft:evocation_fang',
    'minecraft:vex',
    'minecraft:villager',
    'minecraft:wandering_trader',
    'minecraft:zombie_villager',
    'minecraft:phantom',
    'minecraft:pillager',
    'minecraft:ravager',
    'minecraft:iron_golem',
    'minecraft:snow_golem',
    'minecraft:sniffer',
    'minecraft:armor_stand',
    'minecraft:fireworks_rocket',
    'minecraft:lightning_bolt',
    'minecraft:minecart',
    'minecraft:chest_boat',
    'minecraft:chest_boat',
    'minecraft:ender_crystal',
    'minecraft:arrow',
    'minecraft:tnt',
    'minecraft:xp_bottle',
    'minecraft:xp_orb',
    'minecraft:entity',
    'minecraft:entity',
]

const blocks = [
    'minecraft:dark_oak_planks',
    'minecraft:acacia_planks',
    'minecraft:jungle_planks',
    'minecraft:birch_planks',
    'minecraft:spruce_planks',
    'minecraft:black_terracotta',
    'minecraft:red_terracotta',
    'minecraft:green_terracotta',
    'minecraft:brown_terracotta',
    'minecraft:blue_terracotta',
    'minecraft:purple_terracotta',
    'minecraft:cyan_terracotta',
    'minecraft:light_gray_terracotta',
    'minecraft:gray_terracotta',
    'minecraft:pink_terracotta',
    'minecraft:lime_terracotta',
    'minecraft:yellow_terracotta',
    'minecraft:light_blue_terracotta',
    'minecraft:magenta_terracotta',
    'minecraft:orange_terracotta',
    'minecraft:black_concrete_powder',
    'minecraft:red_concrete_powder',
    'minecraft:green_concrete_powder',
    'minecraft:brown_concrete_powder',
    'minecraft:blue_concrete_powder',
    'minecraft:purple_concrete_powder',
    'minecraft:cyan_concrete_powder',
    'minecraft:light_gray_concrete_powder',
    'minecraft:gray_concrete_powder',
    'minecraft:pink_concrete_powder',
    'minecraft:lime_concrete_powder',
    'minecraft:yellow_concrete_powder',
    'minecraft:light_blue_concrete_powder',
    'minecraft:magenta_concrete_powder',
    'minecraft:orange_concrete_powder',
    'minecraft:black_stained_glass',
    'minecraft:red_stained_glass',
    'minecraft:green_stained_glass',
    'minecraft:brown_stained_glass',
    'minecraft:blue_stained_glass',
    'minecraft:purple_stained_glass',
    'minecraft:cyan_stained_glass',
    'minecraft:light_gray_stained_glass',
    'minecraft:gray_stained_glass',
    'minecraft:pink_stained_glass',
    'minecraft:lime_stained_glass',
    'minecraft:yellow_stained_glass',
    'minecraft:light_blue_stained_glass',
    'minecraft:magenta_stained_glass',
    'minecraft:orange_stained_glass',
    'minecraft:black_stained_glass_pane',
    'minecraft:red_stained_glass_pane',
    'minecraft:green_stained_glass_pane',
    'minecraft:brown_stained_glass_pane',
    'minecraft:blue_stained_glass_pane',
    'minecraft:purple_stained_glass_pane',
    'minecraft:cyan_stained_glass_pane',
    'minecraft:light_gray_stained_glass_pane',
    'minecraft:gray_stained_glass_pane',
    'minecraft:pink_stained_glass_pane',
    'minecraft:lime_stained_glass_pane',
    'minecraft:yellow_stained_glass_pane',
    'minecraft:light_blue_stained_glass_pane',
    'minecraft:magenta_stained_glass_pane',
    'minecraft:orange_stained_glass_pane',
    'minecraft:black_concrete',
    'minecraft:red_concrete',
    'minecraft:green_concrete',
    'minecraft:brown_concrete',
    'minecraft:blue_concrete',
    'minecraft:purple_concrete',
    'minecraft:cyan_concrete',
    'minecraft:light_gray_concrete',
    'minecraft:gray_concrete',
    'minecraft:pink_concrete',
    'minecraft:lime_concrete',
    'minecraft:yellow_concrete',
    'minecraft:light_blue_concrete',
    'minecraft:magenta_concrete',
    'minecraft:orange_concrete',
    'minecraft:black_shulker_box',
    'minecraft:red_shulker_box',
    'minecraft:green_shulker_box',
    'minecraft:brown_shulker_box',
    'minecraft:blue_shulker_box',
    'minecraft:purple_shulker_box',
    'minecraft:cyan_shulker_box',
    'minecraft:light_gray_shulker_box',
    'minecraft:gray_shulker_box',
    'minecraft:pink_shulker_box',
    'minecraft:lime_shulker_box',
    'minecraft:yellow_shulker_box',
    'minecraft:light_blue_shulker_box',
    'minecraft:magenta_shulker_box',
    'minecraft:orange_shulker_box',
    'minecraft:pitcher_plant',
    'minecraft:black_carpet',
    'minecraft:red_carpet',
    'minecraft:green_carpet',
    'minecraft:brown_carpet',
    'minecraft:blue_carpet',
    'minecraft:purple_carpet',
    'minecraft:cyan_carpet',
    'minecraft:light_gray_carpet',
    'minecraft:gray_carpet',
    'minecraft:pink_carpet',
    'minecraft:lime_carpet',
    'minecraft:yellow_carpet',
    'minecraft:light_blue_carpet',
    'minecraft:magenta_carpet',
    'minecraft:orange_carpet',
    'minecraft:sniffer_egg',
    'minecraft:dead_horn_coral',
    'minecraft:dead_fire_coral',
    'minecraft:dead_bubble_coral',
    'minecraft:dead_brain_coral',
    'minecraft:dead_tube_coral',
    'minecraft:horn_coral',
    'minecraft:fire_coral',
    'minecraft:bubble_coral',
    'minecraft:brain_coral',
    'minecraft:calibrated_sculk_sensor',
    'minecraft:spruce_fence',
    'minecraft:jungle_fence',
    'minecraft:dark_oak_fence',
    'minecraft:birch_fence',
    'minecraft:acacia_fence',
    'minecraft:pitcher_crop',
    'minecraft:suspicious_gravel',
    'minecraft:dark_oak_log',
    'minecraft:jungle_log',
    'minecraft:birch_log',
    'minecraft:spruce_log',
    'minecraft:torchflower',
    'minecraft:torchflower_crop',
    'minecraft:pink_wool',
    'minecraft:magenta_wool',
    'minecraft:purple_wool',
    'minecraft:blue_wool',
    'minecraft:light_blue_wool',
    'minecraft:cyan_wool',
    'minecraft:green_wool',
    'minecraft:lime_wool',
    'minecraft:yellow_wool',
    'minecraft:orange_wool',
    'minecraft:red_wool',
    'minecraft:brown_wool',
    'minecraft:black_wool',
    'minecraft:gray_wool',
    'minecraft:light_gray_wool',
    'minecraft:decorated_pot',
    'minecraft:pink_petals',
    'minecraft:cherry_leaves',
    'minecraft:cherry_sapling',
    'minecraft:cherry_wood',
    'minecraft:stripped_cherry_wood',
    'minecraft:cherry_wall_sign',
    'minecraft:cherry_trapdoor',
    'minecraft:cherry_standing_sign',
    'minecraft:cherry_stairs',
    'minecraft:cherry_double_slab',
    'minecraft:cherry_slab',
    'minecraft:cherry_pressure_plate',
    'minecraft:cherry_planks',
    'minecraft:cherry_log',
    'minecraft:stripped_cherry_log',
    'minecraft:cherry_hanging_sign',
    'minecraft:cherry_fence_gate',
    'minecraft:cherry_fence',
    'minecraft:cherry_door',
    'minecraft:cherry_button',
    'minecraft:suspicious_sand',
    'minecraft:stripped_bamboo_block',
    'minecraft:bamboo_block',
    'minecraft:chiseled_bookshelf',
    'minecraft:bamboo_mosaic_double_slab',
    'minecraft:bamboo_mosaic_slab',
    'minecraft:bamboo_mosaic_stairs',
    'minecraft:bamboo_hanging_sign',
    'minecraft:bamboo_double_slab',
    'minecraft:bamboo_trapdoor',
    'minecraft:bamboo_wall_sign',
    'minecraft:bamboo_standing_sign',
    'minecraft:bamboo_door',
    'minecraft:bamboo_fence_gate',
    'minecraft:bamboo_fence',
    'minecraft:bamboo_pressure_plate',
    'minecraft:bamboo_slab',
    'minecraft:bamboo_stairs',
    'minecraft:bamboo_button',
    'minecraft:bamboo_planks',
    'minecraft:bamboo_mosaic',
    'minecraft:mangrove_hanging_sign',
    'minecraft:warped_hanging_sign',
    'minecraft:crimson_hanging_sign',
    'minecraft:dark_oak_hanging_sign',
    'minecraft:acacia_hanging_sign',
    'minecraft:jungle_hanging_sign',
    'minecraft:birch_hanging_sign',
    'minecraft:spruce_hanging_sign',
    'minecraft:oak_hanging_sign',
    'minecraft:mangrove_double_slab',
    'minecraft:stripped_mangrove_wood',
    'minecraft:mangrove_wood',
    'minecraft:mangrove_trapdoor',
    'minecraft:mangrove_wall_sign',
    'minecraft:mangrove_standing_sign',
    'minecraft:mangrove_door',
    'minecraft:mangrove_fence_gate',
    'minecraft:mangrove_fence',
    'minecraft:mangrove_pressure_plate',
    'minecraft:mangrove_slab',
    'minecraft:mangrove_stairs',
    'minecraft:mangrove_button',
    'minecraft:mangrove_planks',
    'minecraft:stripped_mangrove_log',
    'minecraft:mangrove_log',
    'minecraft:muddy_mangrove_roots',
    'minecraft:mangrove_roots',
    'minecraft:mud_brick_wall',
    'minecraft:mud_brick_stairs',
    'minecraft:mud_brick_double_slab',
    'minecraft:mud_brick_slab',
    'minecraft:packed_mud',
    'minecraft:mud_bricks',
    'minecraft:mangrove_propagule',
    'minecraft:mud',
    'minecraft:mangrove_leaves',
    'minecraft:ochre_froglight',
    'minecraft:verdant_froglight',
    'minecraft:pearlescent_froglight',
    'minecraft:frog_spawn',
    'minecraft:reinforced_deepslate',
    'minecraft:client_request_placeholder_block',
    'minecraft:sculk_shrieker',
    'minecraft:sculk_catalyst',
    'minecraft:sculk_vein',
    'minecraft:sculk',
    'minecraft:infested_deepslate',
    'minecraft:raw_gold_block',
    'minecraft:raw_copper_block',
    'minecraft:raw_iron_block',
    'minecraft:waxed_oxidized_double_cut_copper_slab',
    'minecraft:waxed_oxidized_cut_copper_slab',
    'minecraft:waxed_oxidized_cut_copper_stairs',
    'minecraft:waxed_oxidized_cut_copper',
    'minecraft:waxed_oxidized_copper',
    'minecraft:black_candle_cake',
    'minecraft:red_candle_cake',
    'minecraft:green_candle_cake',
    'minecraft:brown_candle_cake',
    'minecraft:blue_candle_cake',
    'minecraft:purple_candle_cake',
    'minecraft:cyan_candle_cake',
    'minecraft:light_gray_candle_cake',
    'minecraft:gray_candle_cake',
    'minecraft:pink_candle_cake',
    'minecraft:lime_candle_cake',
    'minecraft:yellow_candle_cake',
    'minecraft:light_blue_candle_cake',
    'minecraft:magenta_candle_cake',
    'minecraft:orange_candle_cake',
    'minecraft:white_candle_cake',
    'minecraft:candle_cake',
    'minecraft:black_candle',
    'minecraft:red_candle',
    'minecraft:green_candle',
    'minecraft:brown_candle',
    'minecraft:blue_candle',
    'minecraft:purple_candle',
    'minecraft:cyan_candle',
    'minecraft:light_gray_candle',
    'minecraft:gray_candle',
    'minecraft:pink_candle',
    'minecraft:lime_candle',
    'minecraft:yellow_candle',
    'minecraft:light_blue_candle',
    'minecraft:magenta_candle',
    'minecraft:orange_candle',
    'minecraft:white_candle',
    'minecraft:candle',
    'minecraft:glow_lichen',
    'minecraft:cracked_deepslate_bricks',
    'minecraft:cracked_deepslate_tiles',
    'minecraft:deepslate_copper_ore',
    'minecraft:deepslate_emerald_ore',
    'minecraft:deepslate_coal_ore',
    'minecraft:deepslate_diamond_ore',
    'minecraft:lit_deepslate_redstone_ore',
    'minecraft:deepslate_redstone_ore',
    'minecraft:deepslate_gold_ore',
    'minecraft:deepslate_iron_ore',
    'minecraft:deepslate_lapis_ore',
    'minecraft:deepslate_brick_double_slab',
    'minecraft:deepslate_tile_double_slab',
    'minecraft:polished_deepslate_double_slab',
    'minecraft:cobbled_deepslate_double_slab',
    'minecraft:chiseled_deepslate',
    'minecraft:deepslate_brick_wall',
    'minecraft:deepslate_brick_stairs',
    'minecraft:deepslate_brick_slab',
    'minecraft:deepslate_bricks',
    'minecraft:deepslate_tile_wall',
    'minecraft:deepslate_tile_stairs',
    'minecraft:deepslate_tile_slab',
    'minecraft:deepslate_tiles',
    'minecraft:polished_deepslate_wall',
    'minecraft:polished_deepslate_stairs',
    'minecraft:polished_deepslate_slab',
    'minecraft:polished_deepslate',
    'minecraft:cobbled_deepslate_wall',
    'minecraft:cobbled_deepslate_stairs',
    'minecraft:cobbled_deepslate_slab',
    'minecraft:cobbled_deepslate',
    'minecraft:deepslate',
    'minecraft:smooth_basalt',
    'minecraft:cave_vines_head_with_berries',
    'minecraft:cave_vines_body_with_berries',
    'minecraft:waxed_weathered_double_cut_copper_slab',
    'minecraft:waxed_exposed_double_cut_copper_slab',
    'minecraft:waxed_double_cut_copper_slab',
    'minecraft:oxidized_double_cut_copper_slab',
    'minecraft:weathered_double_cut_copper_slab',
    'minecraft:exposed_double_cut_copper_slab',
    'minecraft:double_cut_copper_slab',
    'minecraft:waxed_weathered_cut_copper_slab',
    'minecraft:waxed_exposed_cut_copper_slab',
    'minecraft:waxed_cut_copper_slab',
    'minecraft:oxidized_cut_copper_slab',
    'minecraft:weathered_cut_copper_slab',
    'minecraft:exposed_cut_copper_slab',
    'minecraft:cut_copper_slab',
    'minecraft:waxed_weathered_cut_copper_stairs',
    'minecraft:waxed_exposed_cut_copper_stairs',
    'minecraft:waxed_cut_copper_stairs',
    'minecraft:oxidized_cut_copper_stairs',
    'minecraft:weathered_cut_copper_stairs',
    'minecraft:exposed_cut_copper_stairs',
    'minecraft:cut_copper_stairs',
    'minecraft:waxed_weathered_cut_copper',
    'minecraft:waxed_exposed_cut_copper',
    'minecraft:waxed_cut_copper',
    'minecraft:oxidized_cut_copper',
    'minecraft:weathered_cut_copper',
    'minecraft:exposed_cut_copper',
    'minecraft:cut_copper',
    'minecraft:waxed_weathered_copper',
    'minecraft:waxed_exposed_copper',
    'minecraft:waxed_copper',
    'minecraft:oxidized_copper',
    'minecraft:weathered_copper',
    'minecraft:exposed_copper',
    'minecraft:copper_block',
    'minecraft:glow_frame',
    'minecraft:flowering_azalea',
    'minecraft:azalea',
    'minecraft:small_dripleaf_block',
    'minecraft:moss_carpet',
    'minecraft:tinted_glass',
    'minecraft:tuff',
    'minecraft:small_amethyst_bud',
    'minecraft:medium_amethyst_bud',
    'minecraft:large_amethyst_bud',
    'minecraft:amethyst_cluster',
    'minecraft:budding_amethyst',
    'minecraft:amethyst_block',
    'minecraft:calcite',
    'minecraft:azalea_leaves_flowered',
    'minecraft:azalea_leaves',
    'minecraft:big_dripleaf',
    'minecraft:cave_vines',
    'minecraft:spore_blossom',
    'minecraft:moss_block',
    'minecraft:hanging_roots',
    'minecraft:dirt_with_roots',
    'minecraft:dripstone_block',
    'minecraft:lightning_rod',
    'minecraft:copper_ore',
    'minecraft:pointed_dripstone',
    'minecraft:sculk_sensor',
    'minecraft:powder_snow',
    'minecraft:quartz_bricks',
    'minecraft:cracked_nether_bricks',
    'minecraft:chiseled_nether_bricks',
    'minecraft:stripped_warped_hyphae',
    'minecraft:stripped_crimson_hyphae',
    'minecraft:crimson_hyphae',
    'minecraft:warped_hyphae',
    'minecraft:polished_blackstone_wall',
    'minecraft:polished_blackstone_button',
    'minecraft:polished_blackstone_pressure_plate',
    'minecraft:polished_blackstone_double_slab',
    'minecraft:polished_blackstone_slab',
    'minecraft:polished_blackstone_stairs',
    'minecraft:polished_blackstone',
    'minecraft:soul_campfire',
    'minecraft:crying_obsidian',
    'minecraft:nether_gold_ore',
    'minecraft:twisting_vines',
    'minecraft:chain',
    'minecraft:polished_blackstone_brick_double_slab',
    'minecraft:polished_blackstone_brick_slab',
    'minecraft:blackstone_double_slab',
    'minecraft:blackstone_slab',
    'minecraft:gilded_blackstone',
    'minecraft:cracked_polished_blackstone_bricks',
    'minecraft:chiseled_polished_blackstone',
    'minecraft:polished_blackstone_brick_wall',
    'minecraft:blackstone_wall',
    'minecraft:blackstone_stairs',
    'minecraft:polished_blackstone_brick_stairs',
    'minecraft:polished_blackstone_bricks',
    'minecraft:blackstone',
    'minecraft:respawn_anchor',
    'minecraft:ancient_debris',
    'minecraft:netherite_block',
    'minecraft:soul_lantern',
    'minecraft:soul_torch',
    'minecraft:warped_double_slab',
    'minecraft:crimson_double_slab',
    'minecraft:warped_slab',
    'minecraft:crimson_slab',
    'minecraft:warped_pressure_plate',
    'minecraft:crimson_pressure_plate',
    'minecraft:warped_button',
    'minecraft:crimson_button',
    'minecraft:warped_fence_gate',
    'minecraft:crimson_fence_gate',
    'minecraft:warped_fence',
    'minecraft:crimson_fence',
    'minecraft:warped_stairs',
    'minecraft:crimson_stairs',
    'minecraft:warped_wall_sign',
    'minecraft:crimson_wall_sign',
    'minecraft:warped_standing_sign',
    'minecraft:crimson_standing_sign',
    'minecraft:warped_trapdoor',
    'minecraft:crimson_trapdoor',
    'minecraft:warped_door',
    'minecraft:crimson_door',
    'minecraft:warped_planks',
    'minecraft:crimson_planks',
    'minecraft:stripped_warped_stem',
    'minecraft:stripped_crimson_stem',
    'minecraft:target',
    'minecraft:nether_sprouts',
    'minecraft:soul_fire',
    'minecraft:soul_soil',
    'minecraft:polished_basalt',
    'minecraft:basalt',
    'minecraft:warped_nylium',
    'minecraft:crimson_nylium',
    'minecraft:weeping_vines',
    'minecraft:shroomlight',
    'minecraft:warped_fungus',
    'minecraft:crimson_fungus',
    'minecraft:warped_wart_block',
    'minecraft:warped_stem',
    'minecraft:crimson_stem',
    'minecraft:warped_roots',
    'minecraft:crimson_roots',
    'minecraft:lodestone',
    'minecraft:honeycomb_block',
    'minecraft:honey_block',
    'minecraft:beehive',
    'minecraft:bee_nest',
    'minecraft:sticky_piston_arm_collision',
    'minecraft:wither_rose',
    'minecraft:light_block',
    'minecraft:lit_blast_furnace',
    'minecraft:composter',
    'minecraft:wood',
    'minecraft:jigsaw',
    'minecraft:campfire',
    'minecraft:lantern',
    'minecraft:sweet_berry_bush',
    'minecraft:bell',
    'minecraft:loom',
    'minecraft:barrel',
    'minecraft:smithing_table',
    'minecraft:fletching_table',
    'minecraft:cartography_table',
    'minecraft:lit_smoker',
    'minecraft:smoker',
    'minecraft:stonecutter_block',
    'minecraft:blast_furnace',
    'minecraft:grindstone',
    'minecraft:lectern',
    'minecraft:darkoak_wall_sign',
    'minecraft:darkoak_standing_sign',
    'minecraft:acacia_wall_sign',
    'minecraft:acacia_standing_sign',
    'minecraft:jungle_wall_sign',
    'minecraft:jungle_standing_sign',
    'minecraft:birch_wall_sign',
    'minecraft:birch_standing_sign',
    'minecraft:smooth_quartz_stairs',
    'minecraft:red_nether_brick_stairs',
    'minecraft:smooth_stone',
    'minecraft:spruce_wall_sign',
    'minecraft:spruce_standing_sign',
    'minecraft:normal_stone_stairs',
    'minecraft:mossy_cobblestone_stairs',
    'minecraft:end_brick_stairs',
    'minecraft:smooth_sandstone_stairs',
    'minecraft:smooth_red_sandstone_stairs',
    'minecraft:mossy_stone_brick_stairs',
    'minecraft:polished_andesite_stairs',
    'minecraft:polished_diorite_stairs',
    'minecraft:polished_granite_stairs',
    'minecraft:andesite_stairs',
    'minecraft:diorite_stairs',
    'minecraft:granite_stairs',
    'minecraft:double_stone_block_slab4',
    'minecraft:double_stone_block_slab3',
    'minecraft:stone_block_slab4',
    'minecraft:scaffolding',
    'minecraft:bamboo_sapling',
    'minecraft:bamboo',
    'minecraft:stone_block_slab3',
    'minecraft:barrier',
    'minecraft:bubble_column',
    'minecraft:turtle_egg',
    'minecraft:conduit',
    'minecraft:sea_pickle',
    'minecraft:carved_pumpkin',
    'minecraft:spruce_pressure_plate',
    'minecraft:jungle_pressure_plate',
    'minecraft:dark_oak_pressure_plate',
    'minecraft:birch_pressure_plate',
    'minecraft:acacia_pressure_plate',
    'minecraft:spruce_trapdoor',
    'minecraft:jungle_trapdoor',
    'minecraft:dark_oak_trapdoor',
    'minecraft:birch_trapdoor',
    'minecraft:acacia_trapdoor',
    'minecraft:spruce_button',
    'minecraft:jungle_button',
    'minecraft:dark_oak_button',
    'minecraft:birch_button',
    'minecraft:acacia_button',
    'minecraft:dried_kelp_block',
    'minecraft:kelp',
    'minecraft:coral_fan_hang3',
    'minecraft:coral_fan_hang2',
    'minecraft:coral_fan_hang',
    'minecraft:coral_fan_dead',
    'minecraft:coral_fan',
    'minecraft:coral_block',
    'minecraft:tube_coral',
    'minecraft:seagrass',
    'minecraft:blue_ice',
    'minecraft:stripped_oak_log',
    'minecraft:stripped_dark_oak_log',
    'minecraft:stripped_acacia_log',
    'minecraft:stripped_jungle_log',
    'minecraft:stripped_birch_log',
    'minecraft:stripped_spruce_log',
    'minecraft:prismarine_bricks_stairs',
    'minecraft:dark_prismarine_stairs',
    'minecraft:prismarine_stairs',
    'minecraft:stone',
    'minecraft:grass',
    'minecraft:dirt',
    'minecraft:cobblestone',
    'minecraft:oak_planks',
    'minecraft:sapling',
    'minecraft:bedrock',
    'minecraft:flowing_water',
    'minecraft:water',
    'minecraft:flowing_lava',
    'minecraft:lava',
    'minecraft:sand',
    'minecraft:gravel',
    'minecraft:gold_ore',
    'minecraft:iron_ore',
    'minecraft:coal_ore',
    'minecraft:oak_log',
    'minecraft:leaves',
    'minecraft:sponge',
    'minecraft:glass',
    'minecraft:lapis_ore',
    'minecraft:lapis_block',
    'minecraft:dispenser',
    'minecraft:sandstone',
    'minecraft:noteblock',
    'minecraft:bed',
    'minecraft:golden_rail',
    'minecraft:detector_rail',
    'minecraft:sticky_piston',
    'minecraft:web',
    'minecraft:tallgrass',
    'minecraft:deadbush',
    'minecraft:piston',
    'minecraft:piston_arm_collision',
    'minecraft:white_wool',
    'minecraft:yellow_flower',
    'minecraft:red_flower',
    'minecraft:brown_mushroom',
    'minecraft:red_mushroom',
    'minecraft:gold_block',
    'minecraft:iron_block',
    'minecraft:double_stone_block_slab',
    'minecraft:stone_block_slab',
    'minecraft:brick_block',
    'minecraft:tnt',
    'minecraft:bookshelf',
    'minecraft:mossy_cobblestone',
    'minecraft:obsidian',
    'minecraft:torch',
    'minecraft:fire',
    'minecraft:mob_spawner',
    'minecraft:oak_stairs',
    'minecraft:chest',
    'minecraft:redstone_wire',
    'minecraft:diamond_ore',
    'minecraft:diamond_block',
    'minecraft:crafting_table',
    'minecraft:wheat',
    'minecraft:farmland',
    'minecraft:furnace',
    'minecraft:lit_furnace',
    'minecraft:standing_sign',
    'minecraft:wooden_door',
    'minecraft:ladder',
    'minecraft:rail',
    'minecraft:stone_stairs',
    'minecraft:wall_sign',
    'minecraft:lever',
    'minecraft:stone_pressure_plate',
    'minecraft:iron_door',
    'minecraft:wooden_pressure_plate',
    'minecraft:redstone_ore',
    'minecraft:lit_redstone_ore',
    'minecraft:unlit_redstone_torch',
    'minecraft:redstone_torch',
    'minecraft:stone_button',
    'minecraft:snow_layer',
    'minecraft:ice',
    'minecraft:snow',
    'minecraft:cactus',
    'minecraft:clay',
    'minecraft:reeds',
    'minecraft:jukebox',
    'minecraft:oak_fence',
    'minecraft:pumpkin',
    'minecraft:netherrack',
    'minecraft:soul_sand',
    'minecraft:glowstone',
    'minecraft:portal',
    'minecraft:lit_pumpkin',
    'minecraft:cake',
    'minecraft:unpowered_repeater',
    'minecraft:powered_repeater',
    'minecraft:trapdoor',
    'minecraft:monster_egg',
    'minecraft:stonebrick',
    'minecraft:brown_mushroom_block',
    'minecraft:red_mushroom_block',
    'minecraft:iron_bars',
    'minecraft:glass_pane',
    'minecraft:melon_block',
    'minecraft:pumpkin_stem',
    'minecraft:melon_stem',
    'minecraft:vine',
    'minecraft:fence_gate',
    'minecraft:brick_stairs',
    'minecraft:stone_brick_stairs',
    'minecraft:mycelium',
    'minecraft:waterlily',
    'minecraft:nether_brick',
    'minecraft:nether_brick_fence',
    'minecraft:nether_brick_stairs',
    'minecraft:nether_wart',
    'minecraft:enchanting_table',
    'minecraft:brewing_stand',
    'minecraft:cauldron',
    'minecraft:end_portal',
    'minecraft:end_portal_frame',
    'minecraft:end_stone',
    'minecraft:dragon_egg',
    'minecraft:redstone_lamp',
    'minecraft:lit_redstone_lamp',
    'minecraft:dropper',
    'minecraft:activator_rail',
    'minecraft:cocoa',
    'minecraft:sandstone_stairs',
    'minecraft:emerald_ore',
    'minecraft:ender_chest',
    'minecraft:tripwire_hook',
    'minecraft:trip_wire',
    'minecraft:emerald_block',
    'minecraft:spruce_stairs',
    'minecraft:birch_stairs',
    'minecraft:jungle_stairs',
    'minecraft:beacon',
    'minecraft:cobblestone_wall',
    'minecraft:flower_pot',
    'minecraft:carrots',
    'minecraft:potatoes',
    'minecraft:wooden_button',
    'minecraft:skull',
    'minecraft:anvil',
    'minecraft:trapped_chest',
    'minecraft:light_weighted_pressure_plate',
    'minecraft:heavy_weighted_pressure_plate',
    'minecraft:powered_comparator',
    'minecraft:daylight_detector',
    'minecraft:redstone_block',
    'minecraft:quartz_ore',
    'minecraft:hopper',
    'minecraft:quartz_block',
    'minecraft:quartz_stairs',
    'minecraft:double_wooden_slab',
    'minecraft:wooden_slab',
    'minecraft:stained_hardened_clay',
    'minecraft:stained_glass_pane',
    'minecraft:leaves2',
    'minecraft:acacia_log',
    'minecraft:acacia_stairs',
    'minecraft:dark_oak_stairs',
    'minecraft:slime',
    'minecraft:iron_trapdoor',
    'minecraft:prismarine',
    'minecraft:sea_lantern',
    'minecraft:hay_block',
    'minecraft:white_carpet',
    'minecraft:hardened_clay',
    'minecraft:coal_block',
    'minecraft:packed_ice',
    'minecraft:double_plant',
    'minecraft:standing_banner',
    'minecraft:wall_banner',
    'minecraft:daylight_detector_inverted',
    'minecraft:red_sandstone',
    'minecraft:red_sandstone_stairs',
    'minecraft:double_stone_block_slab2',
    'minecraft:stone_block_slab2',
    'minecraft:spruce_fence_gate',
    'minecraft:birch_fence_gate',
    'minecraft:jungle_fence_gate',
    'minecraft:dark_oak_fence_gate',
    'minecraft:acacia_fence_gate',
    'minecraft:spruce_door',
    'minecraft:birch_door',
    'minecraft:jungle_door',
    'minecraft:acacia_door',
    'minecraft:dark_oak_door',
    'minecraft:grass_path',
    'minecraft:frame',
    'minecraft:chorus_flower',
    'minecraft:purpur_block',
    'minecraft:purpur_stairs',
    'minecraft:colored_torch_bp',
    'minecraft:undyed_shulker_box',
    'minecraft:end_bricks',
    'minecraft:frosted_ice',
    'minecraft:end_rod',
    'minecraft:magma',
    'minecraft:nether_wart_block',
    'minecraft:red_nether_brick',
    'minecraft:bone_block',
    'minecraft:structure_void',
    'minecraft:shulker_box',
    'minecraft:purple_glazed_terracotta',
    'minecraft:white_glazed_terracotta',
    'minecraft:orange_glazed_terracotta',
    'minecraft:magenta_glazed_terracotta',
    'minecraft:light_blue_glazed_terracotta',
    'minecraft:yellow_glazed_terracotta',
    'minecraft:lime_glazed_terracotta',
    'minecraft:pink_glazed_terracotta',
    'minecraft:gray_glazed_terracotta',
    'minecraft:silver_glazed_terracotta',
    'minecraft:cyan_glazed_terracotta',
    'minecraft:blue_glazed_terracotta',
    'minecraft:brown_glazed_terracotta',
    'minecraft:green_glazed_terracotta',
    'minecraft:red_glazed_terracotta',
    'minecraft:black_glazed_terracotta',
    'minecraft:concrete',
    'minecraft:concrete_powder',
    'minecraft:chorus_plant',
    'minecraft:stained_glass',
    'minecraft:podzol',
    'minecraft:beetroot',
    'minecraft:observer'
]

world.afterEvents.worldInitialize.subscribe(() => {
    world.getDimension('overworld').runCommandAsync('gamerule sendcommandfeedback false')
    world.getDimension('overworld').runCommandAsync('gamerule commandblockoutput false')
})